@@ -1,11 +1,15 @@
+# -*- coding: utf-8 -*-
 """ python inspection/code generation API """
-from __future__ import absolute_import, division, print_function
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+
 from .code import Code  # noqa
 from .code import ExceptionInfo  # noqa
-from .code import Frame  # noqa
-from .code import Traceback  # noqa
 from .code import filter_traceback  # noqa
+from .code import Frame  # noqa
 from .code import getrawcode  # noqa
-from .source import Source  # noqa
+from .code import Traceback  # noqa
 from .source import compile_ as compile  # noqa
 from .source import getfslineno  # noqa
+from .source import Source  # noqa
