@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """
 per-test stdout/stderr capturing mechanism.
 
@@ -56,13 +57,6 @@ def pytest_load_initial_conftests(early_config, parser, args):
     # make sure that capturemanager is properly reset at final shutdown
     early_config.add_cleanup(capman.stop_global_capturing)
 
-    # make sure logging does not raise exceptions at the end
-    def silence_logging_at_shutdown():
-        if "logging" in sys.modules:
-            sys.modules["logging"].raiseExceptions = False
-
-    early_config.add_cleanup(silence_logging_at_shutdown)
-
     # finally trigger conftest loading but while capturing (issue93)
     capman.start_global_capturing()
     outcome = yield
@@ -365,8 +359,7 @@ class CaptureFixture(object):
         self._captured_err = self.captureclass.EMPTY_BUFFER
 
     def _start(self):
-        # Start if not started yet
-        if getattr(self, "_capture", None) is None:
+        if self._capture is None:
             self._capture = MultiCapture(
                 out=True, err=True, in_=False, Capture=self.captureclass
             )
@@ -396,11 +389,13 @@ class CaptureFixture(object):
 
     def _suspend(self):
         """Suspends this fixture's own capturing temporarily."""
-        self._capture.suspend_capturing()
+        if self._capture is not None:
+            self._capture.suspend_capturing()
 
     def _resume(self):
         """Resumes this fixture's own capturing temporarily."""
-        self._capture.resume_capturing()
+        if self._capture is not None:
+            self._capture.resume_capturing()
 
     @contextlib.contextmanager
     def disabled(self):
@@ -454,6 +449,10 @@ class EncodedFile(object):
         """Ensure that file.name is a string."""
         return repr(self.buffer)
 
+    @property
+    def mode(self):
+        return self.buffer.mode.replace("b", "")
+
     def __getattr__(self, name):
         return getattr(object.__getattribute__(self, "buffer"), name)
 
@@ -463,6 +462,7 @@ CaptureResult = collections.namedtuple("CaptureResult", ["out", "err"])
 
 class MultiCapture(object):
     out = err = in_ = None
+    _state = None
 
     def __init__(self, out=True, err=True, in_=True, Capture=None):
         if in_:
@@ -473,9 +473,16 @@ class MultiCapture(object):
             self.err = Capture(2)
 
     def __repr__(self):
-        return "<MultiCapture out=%r err=%r in_=%r>" % (self.out, self.err, self.in_)
+        return "<MultiCapture out=%r err=%r in_=%r _state=%r _in_suspended=%r>" % (
+            self.out,
+            self.err,
+            self.in_,
+            self._state,
+            getattr(self, "_in_suspended", "<UNSET>"),
+        )
 
     def start_capturing(self):
+        self._state = "started"
         if self.in_:
             self.in_.start()
         if self.out:
@@ -493,6 +500,7 @@ class MultiCapture(object):
         return out, err
 
     def suspend_capturing(self, in_=False):
+        self._state = "suspended"
         if self.out:
             self.out.suspend()
         if self.err:
@@ -502,6 +510,7 @@ class MultiCapture(object):
             self._in_suspended = True
 
     def resume_capturing(self):
+        self._state = "resumed"
         if self.out:
             self.out.resume()
         if self.err:
@@ -512,9 +521,9 @@ class MultiCapture(object):
 
     def stop_capturing(self):
         """ stop capturing and reset capturing streams """
-        if hasattr(self, "_reset"):
+        if self._state == "stopped":
             raise ValueError("was already stopped")
-        self._reset = True
+        self._state = "stopped"
         if self.out:
             self.out.done()
         if self.err:
@@ -542,6 +551,7 @@ class FDCaptureBinary(object):
     """
 
     EMPTY_BUFFER = b""
+    _state = None
 
     def __init__(self, targetfd, tmpfile=None):
         self.targetfd = targetfd
@@ -568,9 +578,10 @@ class FDCaptureBinary(object):
             self.tmpfile_fd = tmpfile.fileno()
 
     def __repr__(self):
-        return "<FDCapture %s oldfd=%s>" % (
+        return "<FDCapture %s oldfd=%s _state=%r>" % (
             self.targetfd,
             getattr(self, "targetfd_save", None),
+            self._state,
         )
 
     def start(self):
@@ -581,6 +592,7 @@ class FDCaptureBinary(object):
             raise ValueError("saved filedescriptor not valid anymore")
         os.dup2(self.tmpfile_fd, self.targetfd)
         self.syscapture.start()
+        self._state = "started"
 
     def snap(self):
         self.tmpfile.seek(0)
@@ -597,14 +609,17 @@ class FDCaptureBinary(object):
         os.close(targetfd_save)
         self.syscapture.done()
         _attempt_to_close_capture_file(self.tmpfile)
+        self._state = "done"
 
     def suspend(self):
         self.syscapture.suspend()
         os.dup2(self.targetfd_save, self.targetfd)
+        self._state = "suspended"
 
     def resume(self):
         self.syscapture.resume()
         os.dup2(self.tmpfile_fd, self.targetfd)
+        self._state = "resumed"
 
     def writeorg(self, data):
         """ write to original file descriptor. """
@@ -632,6 +647,7 @@ class FDCapture(FDCaptureBinary):
 class SysCapture(object):
 
     EMPTY_BUFFER = str()
+    _state = None
 
     def __init__(self, fd, tmpfile=None):
         name = patchsysdict[fd]
@@ -644,8 +660,17 @@ class SysCapture(object):
                 tmpfile = CaptureIO()
         self.tmpfile = tmpfile
 
+    def __repr__(self):
+        return "<SysCapture %s _old=%r, tmpfile=%r _state=%r>" % (
+            self.name,
+            self._old,
+            self.tmpfile,
+            self._state,
+        )
+
     def start(self):
         setattr(sys, self.name, self.tmpfile)
+        self._state = "started"
 
     def snap(self):
         res = self.tmpfile.getvalue()
@@ -657,12 +682,15 @@ class SysCapture(object):
         setattr(sys, self.name, self._old)
         del self._old
         _attempt_to_close_capture_file(self.tmpfile)
+        self._state = "done"
 
     def suspend(self):
         setattr(sys, self.name, self._old)
+        self._state = "suspended"
 
     def resume(self):
         setattr(sys, self.name, self.tmpfile)
+        self._state = "resumed"
 
     def writeorg(self, data):
         self._old.write(data)
