@@ -694,7 +694,7 @@ def raises(expected_exception, *args, **kwargs):
         return RaisesContext(expected_exception, message, match_expr)
     elif isinstance(args[0], str):
         warnings.warn(deprecated.RAISES_EXEC, stacklevel=2)
-        code, = args
+        (code,) = args
         assert isinstance(code, str)
         frame = sys._getframe(1)
         loc = frame.f_locals.copy()
