@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """ discovery and running of std-library "unittest" style tests. """
 from __future__ import absolute_import
 from __future__ import division
@@ -87,6 +88,9 @@ def _make_xunit_fixture(obj, setup_name, teardown_name, scope, pass_self):
 
     @pytest.fixture(scope=scope, autouse=True)
     def fixture(self, request):
+        if getattr(self, "__unittest_skip__", None):
+            reason = self.__unittest_skip_why__
+            pytest.skip(reason)
         if setup is not None:
             if pass_self:
                 setup(self, request.function)
@@ -110,6 +114,7 @@ class TestCaseFunction(Function):
     def setup(self):
         self._testcase = self.parent.obj(self.name)
         self._fix_unittest_skip_decorator()
+        self._obj = getattr(self._testcase, self.name)
         if hasattr(self, "_request"):
             self._request._fillfixtures()
 
@@ -128,6 +133,7 @@ class TestCaseFunction(Function):
 
     def teardown(self):
         self._testcase = None
+        self._obj = None
 
     def startTest(self, testcase):
         pass
